
namedspace release notes
========================
1.1.1
=====
* Added LICENSE file.

1.1.0
=====
* Add ability for optional fields to return None instead of
  raising an AttributeError.

1.0.1
=====
 * Fix bug in generated class __repr__ method.
 * Refactor and add additional documentation and doctests.
 * Add html documentation.
 * Move release notes to root of project.
 * Move tests to root of project.

1.0.0
=====
 * Initial release.
